---
name: "\U0001F41B Bug report"
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

Make sure you've completed the following steps before submitting your issue --- thank you!

1. Search the [issue tracker][] to verify that this hasn't already been reported.
   +1 or comment there if it has.
2. Consider asking first in our chat room at the [Unitary Fund Discord][].
3. If possible, make a PR with a new, failing test to give us a starting point 
   to work on!

[issue tracker]: https://github.com/boschmitt/tweedledum/issues
[Unitary Fund Discord]: http://discord.unitary.fund/

*After reading, remove this checklist. Thanks for helping us improve 
`tweedledum`!*

### Describe the bug
<!-- A clear and concise description of what the bug is. -->

### Reproducible example code
<!-- The code should be minimal, have no external dependencies, isolate the
     function(s) that cause the issue. It should also be _complete_ C++ or Python 
     snippets that can be easily compiled and run to diagnose the issue. -->

### Expected behavior
<!-- A clear and concise description of what you expected to happen. -->

### Information
<!-- If you are using tweedledum from python _and_ have not built it from source
     then delete the 'C++ compiler' entry. If you are using it as a C++ library
     then delete 'Python version' entry -->

- **tweedledum version**:
- **Python version**: 
- **C++ compiler**:
- **Operating system**:

### Additional context
<!-- Add any other context about the problem here. Delete if its not needed -->
